import mongoose from 'mongoose'
const ObjectId = mongoose.Schema.Types.ObjectId

export const notification = {
  finderId: {
    type: Number,
    index: true,
  },
  pendingDelete: {
    type: Date,
    index: true,
  },
  isDeleted: Boolean,
  undeleteToken: {
    type: String,
    unique: true,
    sparse: true,
  },
  backupInfo: Object,
  lastModified: {
    type: Date,
    default: Date.now,
  },
  createdBy: {
    type: ObjectId,
    ref: 'User',
  },
  externalId: {
    type: String,
    index: true,
  },
  rbnAtsId: String,
  lastDuplicateCheck: Date,
  mergedTo: ObjectId,
  potentialDuplicates: [{
    person: ObjectId,
    resolution: {
      type: String,
      enum: ['none', 'merged', 'not-duplicate'],
      default: 'none',
    },
    resolvedBy: {
      name: {
        first: String,
        last: String,
      },
      finderId: Number,
      user: {
        type: ObjectId,
        ref: 'User',
      },
    },
    resolvedAt: Date,
    mergeDetails: [{
      name: {
        last: String,
        first: String,
      },
      email: String,
      phone: String,
    }],
  }],
  linkedInUrl: String,
  username: String,
  email: {
    type: String,
    index: true,
  },
  knownEmails: [String],
  phone: String,
  name: {
    first: String,
    last: String,
  },
  address: {
    street: String,
    zip: String,
    town: String,
    country: String,
  },
  nationality: String,
  expertise: [String],
  interviews: [{
    author: {
      name: {
        first: String,
        last: String,
      },
      finderId: Number,
      user: {
        type: ObjectId,
        ref: 'User',
      },
    },
    date: {
      type: Date,
      default: Date.now,
    },
    started: {
      type: Date,
      default: Date.now,
    },
    firstSaved: {
      type: Date,
      index: true,
    },
    industry: String,
    legacy: Boolean,
    edits: [{
      type: ObjectId,
      ref: 'InterviewEdit',
    }],
    editingStartedAt: {
      type: ObjectId,
      ref: 'InterviewEdit',
    },
    currentText: String,
    state: {
      type: String,
      index: true,
      enum: ['new', 'saved', 'editing', 'deleted', 'canceled'],
      default: 'new',
    },
    commission: {
      type: ObjectId,
      ref: 'Commission',
    },
    lastModified: {
      type: Date,
      index: true,
      default: Date.now,
    },
  }],
  overview: [{
    author: {
      name: {
        first: String,
        last: String,
      },
      finderId: Number,
      user: {
        type: ObjectId,
        ref: 'User',
      },
    },
    text: String,
    date: {
      type: Date,
      default: Date.now,
    },
    editStart: {
      type: Date,
      default: Date.now,
    },
    customerId: {
      type: String,
      index: true,
    },
  }],
  introductionText: String,
  finder: {
    profileComment: String,
    education: String,
    additionalInformation: String,
    employeeWishes: String,
  },
  myProfile: {
    education: [{
      finderId: Number,
      externalId: String,
      degree: String,
      graduationYear: String,
      inProgress: Boolean,
      school: String,
      text: String,
      state: {
        type: String,
        index: true,
        enum: ['new', 'saved', 'editing', 'deleted'],
        default: 'saved',
      },
      editClone: {
        author: {
          name: {
            first: String,
            last: String,
          },
          finderId: Number,
          user: {
            type: ObjectId,
            ref: 'User',
          },
        },
        overwriteable: Boolean,
        date: {
          type: Date,
          default: Date.now,
        },
        lastEdited: Date,
        degree: String,
        graduationYear: String,
        inProgress: Boolean,
        school: String,
        text: String,
      },
    }],
    workExperience: [{
      finderId: Number,
      externalId: String,
      employer: String,
      position: String,
      begin: Date,
      end: Date,
      termOfNotice: Number,
      termOfNoticeUnit: {
        type: String,
        enum: ['w', 'm'],
        default: 'w',
      },
      location: String,
      references: String,
      text: String,
      state: {
        type: String,
        index: true,
        enum: ['new', 'saved', 'editing', 'deleted'],
        default: 'saved',
      },
      editClone: {
        author: {
          name: {
            first: String,
            last: String,
          },
          finderId: Number,
          user: {
            type: ObjectId,
            ref: 'User',
          },
        },
        overwriteable: Boolean,
        date: {
          type: Date,
          default: Date.now,
        },
        lastEdited: Date,
        employer: String,
        position: String,
        begin: Date,
        end: Date,
        termOfNotice: Number,
        termOfNoticeUnit: String,
        location: String,
        references: String,
        text: String,
      },
    }],
    jobApplications: [{
      externalId: String,
      date: {
        type: Date,
        index: true,
      },
      availability: String,
      additionalAvailabilityInfo: String,
      position: {
        name: String,
        businessBranch: String,
        city: String,
        externalId: {
          type: String,
          index: true,
        },
        commission: {
          type: ObjectId,
          index: true,
        },
      },
      text: String,
      desiredSalary: String,
      salaryPreferenceAnswer: {
        amount: Number,
        period: {
          type: String,
          enum: ['month', 'hour', 'year'],
        },
        currency: {
          type: String,
          enum: ['EUR', 'SEK', 'USD'],
        },
        freeform: String,
      },
      cover: String,
      attachments: [ObjectId],
      source: String,
      expectations: [{
        label: String,
        fulfilled: Boolean,
      }],
      requirements: [{
        label: String,
        fulfilled: Boolean,
      }],
    }],
    languages: [{
      language: String,
      languageId: {
        type: ObjectId,
        ref: 'Language',
      },
      proficiency: Number,
    }],
    languagesEditClone: {
      state: {
        type: String,
        index: true,
        enum: ['saved', 'editing'],
        default: 'saved',
      },
      author: {
        name: {
          first: String,
          last: String,
        },
        finderId: Number,
        user: {
          type: ObjectId,
          ref: 'User',
        },
      },
      date: {
        type: Date,
        default: Date.now,
      },
      languages: [{
        language: String,
        languageId: {
          type: ObjectId,
          ref: 'Language',
        },
        proficiency: Number,
      }],
    },
    attachments: [{
      type: String,
      employeeNotAllowedToDelete: Boolean,
      displayName: String,
      filename: String,
      mimeType: String,
      date: Date,
      finderId: {
        type: Number,
        index: true,
      },
      externalId: String,
      integrationPointId: Object,
      uploadedBy: {
        name: {
          first: String,
          last: String,
        },
        finderId: Number,
        user: {
          type: ObjectId,
          ref: 'User',
        },
      },
      uploadedBySelf: Boolean,
      placeholder: Boolean,
      pending: Boolean,
      source: {
        type: String,
        enum: ['o2', 'ura'],
      },
      storage: {
        type: String,
        enum: ['finder', 's3', 'fs'],
      },
      uploadedToPerson: ObjectId,
    }],
    exists: Boolean,
  },
  ssn: String,
  sex: String,
  iban: String,
  taxNumber: Number,
  employmentContracts: [{
    finderId: {
      type: Number,
      index: true,
    },
    begin: String,
    end: String,
    customer: String,
    profession: String,
    hours: String,
    endReason: String,
    creationDate: Date,
  }],
  contracts: [{
    finderId: {
      type: Number,
      index: true,
    },
    begin: Date,
    end: Date,
    description: String,
    profession: String,
    allowance: String,
    pay: String,
    price: String,
    trips: String,
    meals: String,
    tools: String,
    company: {
      type: ObjectId,
      index: true,
      ref: 'Company',
    },
    commission: {
      type: ObjectId,
      index: true,
      ref: 'Commission',
    },
    industry: String,
    workExperience: {
      type: ObjectId,
    },
    tes: String,
    priceMultiplier: Number,
    createdAt: Date,
    valid: {
      type: Boolean,
    },
    synced: Boolean,
    frozen: {
      type: Boolean,
    },
    updatedBy: {
      name: {
        first: String,
        last: String,
      },
      finderId: Number,
      user: {
        type: ObjectId,
        ref: 'User',
      },
    },
    error: {
      type: ObjectId,
    },
    madeByR2: Boolean,
  }],
  comments: [{
    comment: String,
    commission: ObjectId,
    author: {
      name: {
        first: String,
        last: String,
      },
      finderId: Number,
      user: {
        type: ObjectId,
        ref: 'User',
      },
    },
    date: Date,
    industry: String,
    deleted: Boolean,
    type: {
      type: String,
      enum: ['search-show', 'search-hide', 'employable', 'not-employable', 'comment', 'suitability', 'commission-comment'],
    },
    rating: Number,
    edits: [{
      type: ObjectId,
      ref: 'CommentEdit',
    }],
    editClone: {
      exists: {
        type: Boolean,
        index: true,
      },
      comment: String,
      author: {
        name: {
          first: String,
          last: String,
        },
        finderId: Number,
        user: {
          type: ObjectId,
          ref: 'User',
        },
      },
      date: Date,
    },
  }],
  rbnInterviews: [{
    type: ObjectId,
    index: true,
    ref: 'RbnInterview',
  }],
  latestRbnInterview: Date,
  hidden: Boolean,
  interviewedByIndustries: [String],
  notEmployableInIndustries: [String],
  birthDate: Date,
  computedAvailableAt: Date,
  availableAt: Date,
  availableUntil: Date,
  timeNeeded: {
    amount: Number,
    unit: String,
  },
  hasCar: Boolean,
  synced: Boolean,
  editClone: {
    exists: Boolean,
    email: String,
    phone: String,
    name: {
      first: String,
      last: String,
    },
    address: {
      street: String,
      zip: String,
      town: String,
      country: String,
    },
    ssn: String,
    sex: String,
    iban: String,
    taxNumber: String,
  },
  profileSearchKeys: [String],
  unsaved: Boolean,
  transferredToFinderBasket: Date,
  reservedBy: [{
    user: {
      type: ObjectId,
      ref: 'User',
    },
    name: {
      last: String,
      first: String,
    },
    date: {
      type: Date,
      default: Date.now,
    },
    checked: Boolean,
  }],
  commissionInfo: [{
    commission: {
      type: ObjectId,
      index: true,
      ref: 'Commission',
    },
    rating: Number,
    ratings: [{
      rating: Number,
      user: {
        name: {
          first: String,
          last: String,
        },
        finderId: Number,
        user: {
          type: ObjectId,
          ref: 'User',
        },
      },
      date: Date,
    }],
    markedForSelection: Date,
    selected: Date,
    reserved: Date,
    application: Date,
    applicationUpdated: Date,
    terminated: Date,
    terminationMessageSent: Date,
    commissionDeleted: {
      date: Date,
      wasReserved: Date,
    },
    pipelineState: String,
    aptitudeTestsSent: {
      initial: Date,
      advanced: Date,
    },
    aptitudeTestResults: {
      initial: {
        testSet: String,
        allDone: Boolean,
        testResults: [{
          testId: String,
          grade: Number,
          name: String,
          done: Date,
          resultFileLocation: String,
        }],
      },
      advanced: {
        testSet: String,
        allDone: Boolean,
        testResults: [{
          testId: String,
          grade: Number,
          name: String,
          done: Date,
          resultFileLocation: String,
        }],
      },
    },
    workExperience: {
      type: ObjectId,
    },
    interviews: [Date],
    rbnInterview: {
      sent: Date,
      answered: Date,
    },
    interviewDate: {
      stateActivated: Date,
      date: Date,
      duration: Number,
      notified: Date,
      interviewer: ObjectId,
    },
    introduction: {
      stateActivated: Date,
      date: Date,
      exportedToIntroductionTool: Date,
      introductionCreated: Date,
      introductionToolId: String,
      recruiterReview: String,
      recruiterHighlight: String,
      introducedBy: {
        name: {
          first: String,
          last: String,
        },
        finderId: Number,
        user: {
          type: ObjectId,
          ref: 'User',
        },
      },
      introductionComments: [{
        author: {
          name: {
            last: String,
            first: String,
          },
          email: String,
          jelppId: String,
        },
        comment: String,
        createdAt: Date,
        decision: {
          type: String,
          enum: ['none', 'accept', 'process', 'reject'],
          default: 'none',
        },
      }],
    },
    contract: {
      exists: Boolean,
      host: String,
      externalId: String,
      notDeletable: Boolean,
      date: Date,
    },
    jobPeriod: {
      startDate: Date,
      endDate: Date,
    },
  }],
  integrationPointId: Object,
  customerId: {
    type: String,
    index: true,
  },
}