// tslint:disable array-type
export interface NotificationBase<IDType, DateType, Defaultable> {
  _id: IDType
  finderId: number
  pendingDelete: DateType
  isDeleted: boolean
  undeleteToken: string
  backupInfo: any
  lastModified: DateType | Defaultable
  createdBy: IDType
  externalId: string
  rbnAtsId: string
  lastDuplicateCheck: DateType
  mergedTo: IDType
  potentialDuplicates: Array<{
    person: IDType
    resolution: 'none' | 'merged' | 'not-duplicate'
    resolvedBy: {
      name: {
        first: string
        last: string
      }
      finderId: number
      user?: IDType
    }
    resolvedAt: DateType
    mergeDetails: Array<{
      name: {
        last: string
        first: string
      }
      email: string
      phone: string
    }>
  }>
  linkedInUrl: string
  username: string
  email: string
  knownEmails: Array<string>
  phone: string
  name: {
    first: string
    last: string
  }
  address: {
    street: string
    zip: string
    town: string
    country: string
  }
  nationality: string
  expertise: Array<string>
  interviews: Array<{
    author: {
      name: {
        first: string
        last: string
      }
      finderId: number
      user?: IDType
    }
    date: DateType | Defaultable
    started: DateType | Defaultable
    firstSaved: DateType
    industry: string
    legacy: boolean
    edits: Array<IDType>
    editingStartedAt: IDType
    currentText: string
    state: 'new' | 'saved' | 'editing' | 'deleted' | 'canceled'
    commission: IDType
    lastModified: DateType | Defaultable
  }>
  overview: Array<{
    author: {
      name: {
        first: string
        last: string
      }
      finderId: number
      user?: IDType
    }
    text: string
    date: DateType | Defaultable
    editStart: DateType | Defaultable
    customerId: string
  }>
  introductionText: string
  finder: {
    profileComment: string
    education: string
    additionalInformation: string
    employeeWishes: string
  }
  myProfile: {
    education: Array<{
      finderId: number
      externalId: string
      degree: string
      graduationYear: string
      inProgress: boolean
      school: string
      text: string
      state: 'new' | 'saved' | 'editing' | 'deleted'
      editClone: {
        author: {
          name: {
            first: string
            last: string
          }
          finderId: number
          user?: IDType
        }
        overwriteable: boolean
        date: DateType | Defaultable
        lastEdited: DateType
        degree: string
        graduationYear: string
        inProgress: boolean
        school: string
        text: string
      }
    }>
    workExperience: Array<{
      finderId: number
      externalId: string
      employer: string
      position: string
      begin: DateType
      end: DateType
      termOfNotice: number
      termOfNoticeUnit: 'w' | 'm'
      location: string
      references: string
      text: string
      state: 'new' | 'saved' | 'editing' | 'deleted'
      editClone: {
        author: {
          name: {
            first: string
            last: string
          }
          finderId: number
          user?: IDType
        }
        overwriteable: boolean
        date: DateType | Defaultable
        lastEdited: DateType
        employer: string
        position: string
        begin: DateType
        end: DateType
        termOfNotice: number
        termOfNoticeUnit: string
        location: string
        references: string
        text: string
      }
    }>
    jobApplications: Array<{
      externalId: string
      date: DateType
      availability: string
      additionalAvailabilityInfo: string
      position: {
        name: string
        businessBranch: string
        city: string
        externalId: string
        commission: IDType
      }
      text: string
      desiredSalary: string
      salaryPreferenceAnswer: {
        amount: number
        period: 'month' | 'hour' | 'year'
        currency: 'EUR' | 'SEK' | 'USD'
        freeform: string
      }
      cover: string
      attachments: Array<IDType>
      source: string
      expectations: Array<{
        label: string
        fulfilled: boolean
      }>
      requirements: Array<{
        label: string
        fulfilled: boolean
      }>
    }>
    languages: Array<{
      language: string
      languageId: IDType
      proficiency: number
    }>
    languagesEditClone: {
      state: 'saved' | 'editing'
      author: {
        name: {
          first: string
          last: string
        }
        finderId: number
        user?: IDType
      }
      date: DateType | Defaultable
      languages: Array<{
        language: string
        languageId: IDType
        proficiency: number
      }>
    }
    attachments: Array<{
      type: string
      employeeNotAllowedToDelete: boolean
      displayName: string
      filename: string
      mimeType: string
      date: DateType
      finderId: number
      externalId: string
      integrationPointId: any
      uploadedBy: {
        name: {
          first: string
          last: string
        }
        finderId: number
        user?: IDType
      }
      uploadedBySelf: boolean
      placeholder: boolean
      pending: boolean
      source: 'o2' | 'ura'
      storage: 'finder' | 's3' | 'fs'
      uploadedToPerson: IDType
    }>
    exists: boolean
  }
  ssn: string
  sex: string
  iban: string
  taxNumber: number
  employmentContracts: Array<{
    finderId: number
    begin: string
    end: string
    customer: string
    profession: string
    hours: string
    endReason: string
    creationDate: DateType
  }>
  contracts: Array<{
    finderId: number
    begin: DateType
    end: DateType
    description: string
    profession: string
    allowance: string
    pay: string
    price: string
    trips: string
    meals: string
    tools: string
    company?: IDType
    commission?: IDType
    industry: string
    workExperience: IDType
    tes: string
    priceMultiplier: number
    createdAt: DateType
    valid: boolean | Defaultable
    synced: boolean
    frozen: boolean | Defaultable
    updatedBy: {
      name: {
        first: string
        last: string
      }
      finderId: number
      user?: IDType
    }
    error: IDType
    madeByR2: boolean
  }>
  comments: Array<{
    comment: string
    commission: IDType
    author: {
      name: {
        first: string
        last: string
      }
      finderId: number
      user?: IDType
    }
    date: DateType
    industry: string
    deleted: boolean
    type: 'search-show' | 'search-hide' | 'employable' | 'not-employable' | 'comment' | 'suitability' | 'commission-comment'
    rating: number
    edits: Array<IDType>
    editClone: {
      exists: boolean
      comment: string
      author: {
        name: {
          first: string
          last: string
        }
        finderId: number
        user?: IDType
      }
      date: DateType
    }
  }>
  rbnInterviews: Array<IDType>
  latestRbnInterview: DateType
  hidden: boolean
  interviewedByIndustries: Array<string>
  notEmployableInIndustries: Array<string>
  birthDate: DateType
  computedAvailableAt: DateType
  availableAt: DateType
  availableUntil: DateType
  timeNeeded: {
    amount: number
    unit: string
  }
  hasCar: boolean
  synced: boolean
  editClone: {
    exists: boolean
    email: string
    phone: string
    name: {
      first: string
      last: string
    }
    address: {
      street: string
      zip: string
      town: string
      country: string
    }
    ssn: string
    sex: string
    iban: string
    taxNumber: string
  }
  profileSearchKeys: Array<string>
  unsaved: boolean
  transferredToFinderBasket: DateType
  reservedBy: Array<{
    user: IDType
    name: {
      last: string
      first: string
    }
    date: DateType | Defaultable
    checked: boolean
  }>
  commissionInfo: Array<{
    commission: IDType
    rating: number
    ratings: Array<{
      rating: number
      user: {
        name: {
          first: string
          last: string
        }
        finderId: number
        user?: IDType
      }
      date: DateType
    }>
    markedForSelection: DateType
    selected: DateType
    reserved: DateType
    application: DateType
    applicationUpdated: DateType
    terminated: DateType
    terminationMessageSent: DateType
    commissionDeleted: {
      date: DateType
      wasReserved: DateType
    }
    pipelineState: string
    aptitudeTestsSent: {
      initial: DateType
      advanced: DateType
    }
    aptitudeTestResults: {
      initial: {
        testSet: string
        allDone: boolean
        testResults: Array<{
          testId: string
          grade: number
          name: string
          done: DateType
          resultFileLocation: string
        }>
      }
      advanced: {
        testSet: string
        allDone: boolean
        testResults: Array<{
          testId: string
          grade: number
          name: string
          done: DateType
          resultFileLocation: string
        }>
      }
    }
    workExperience: IDType
    interviews: Array<DateType>
    rbnInterview: {
      sent: DateType
      answered: DateType
    }
    interviewDate: {
      stateActivated: DateType
      date: DateType
      duration: number
      notified: DateType
      interviewer: IDType
    }
    introduction: {
      stateActivated: DateType
      date: DateType
      exportedToIntroductionTool: DateType
      introductionCreated: DateType
      introductionToolId: string
      recruiterReview: string
      recruiterHighlight: string
      introducedBy: {
        name: {
          first: string
          last: string
        }
        finderId: number
        user?: IDType
      }
      introductionComments: Array<{
        author: {
          name: {
            last: string
            first: string
          }
          email: string
          jelppId: string
        }
        comment: string
        createdAt: DateType
        decision: 'none' | 'accept' | 'process' | 'reject'
      }>
    }
    contract: {
      exists: boolean
      host: string
      externalId: string
      notDeletable: boolean
      date: DateType
    }
    jobPeriod: {
      startDate: DateType
      endDate: DateType
    }
  }>
  integrationPointId: any
  customerId: string
}