import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const nameArray = [
  new Complex({
    language: {type: String, optional: true},
    name: String
  })
]
const schema: Schema = {
  fields: {
    _id: {type: ObjectId, optionalIn: ['json-create', 'json-update']},
    name: nameArray,
    subtypes: [
      new Complex({
        _id: ObjectId,
        name: nameArray
      })
    ],
    indefinitelyValid: Boolean,
    defaultDuration: {type: new Complex({
      unit: { type: String, enum: ['years', 'months', 'weeks', 'days']},
      value: Number
    }), optional: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('certificationTypeMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('CertificationType', schema, 'typescript', { omitExtraExports: true })
  },
  get jsonCreate() {
    return toJSONSchema('certificationTypeJsonCreateSchema', schema, false, 'json-create')
  },
  get jsonUpdate() {
    return toJSONSchema('certificationTypeJsonUpdateSchema', schema, false, 'json-update')
  }
}
