import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {JMAttachment} from './jm-attachment'

const jmcAuthor = new Complex({
  r2Id: {type: ObjectId, optional: true},
  uraId: {type: ObjectId, optional: true},
  name: new Complex({
    last: String,
    first: String
  })
})

const schema: Schema = {
  fields: {
    _id: {type: ObjectId, optionalIn: ['json-create']},
    certificationType: {
      type: ObjectId,
      mongooseRef: 'certificationtype',
    },
    notes: {type: String, optional: true},
    subtypes: {optional: true, type: [{
      type: ObjectId
    }]},
    r2PersonId: {type: ObjectId, index: true, optional: true},
    uraPersonId: {type: ObjectId, index: true, optional: true},
    confirmed: {type: Date, optional: true},
    creationDate: { type: Date, mongooseDefault: now, optional: true},
    createdBy: jmcAuthor,
    confirmedBy: {type: jmcAuthor, optional: true},
    validFrom: {type: Date, optional: true},
    validUntil: {type: Date, optional: true},
    picture: {type: JMAttachment, optional: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('certificationMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Certification', schema, 'typescript', { omitExtraExports: true })
  },
  get jsonCreate() {
    return toJSONSchema('certificationJsonCreateSchema', schema, false, 'json-create')
  },
  get jsonUpdate() {
    return toJSONSchema('certificationJsonUpdateSchema', schema, false, 'json-update', true)
  }
}
