import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'

const normalVisibilities = ['creator', 'industry', 'global', 'fallback', 'finder-applications']

const schema: Schema = {
  fields: {
    _id: ObjectId,
    customerId: String,
    name: String,
    hasBeenAppliedWith: Boolean,
    hasTemplateBeenDeleted: Boolean,
    basedOn: ObjectId, // ref to ApplicationForm

    // Template-specific fields
    isTemplate: Boolean,
    defaultTemplateFrom: Date,
    visibility: {type: String, enum: [...normalVisibilities, 'hidden']},
    visibilityBeforeDelete: {type: String, enum: normalVisibilities},

    // Used in both templates and non-templates
    createdBy: R2Author,
    industry: String,
    language: String,
    applicationSentUIMessage: String, // TODO: figure out if having this here is a good idea or not
    applicationSentEmailMessage: String, // TODO: figure out if having this here is a good idea or not
    useExternalForm: Boolean,
    externalFormURL: String,
    isDraft: Boolean,
    o2FormType: {type: String, enum: ['short', 'long']},
    questions: [new Complex({
      _id: ObjectId,
      type: {type: String, enum: ['text', 'video', 'select-one', 'select-many', 'salary-preference', 'car-availability', 'start-date', 'cv', 'attachments', 'requirements', 'expectations']},
      isAnswerRequired: Boolean,
      label: String,
      description: String,
      isUnmodifiableQuestion: Boolean,
      legacyField: String,

      options: new Complex({
        items: [String],
        period: {type: String, enum: ['month', 'hour', 'year']},
        currency: {type: String, enum: ['EUR', 'SEK', 'USD']},
        freeform: {type: Boolean}, // for job postings before urapalvelu
        rbnIntegration: new Complex({
          rbnOneId: {type: String, index: true},
          interviewName: {type: String, optional: true},
          endTime: {type: Date, optional: true},
          language: {type: String, optional: true},
          answerableQuestions: {type: Number, optional: true},
          questions: {
            optional: true,
            type: [new Complex({
              title: String,
              answerable: Boolean
            })]
          }
        }),
      })
    })],

    convertedFromLegacyJobPosting: Boolean
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('applicationFormMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('ApplicationForm', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
