import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    author: R2Author,
    text: String,
    date: { type: Date, mongooseDefault: now },
    editStart: { type: Date, mongooseDefault: now},
    customerId: {type: String, index: true}
  }
}

export const R2AuthoredText = schema

export default {
  get mongoose() {
    return toMongooseSchema('authoredTextMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('AuthoredText', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
