import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    commissionId: {type: ObjectId, mongooseRef: 'Commission'},
    personId: {type:ObjectId, mongooseRef: 'Person'},
    companyId: {type:ObjectId, mongooseRef: 'Company'},
    customerId: {type: String, index: true},
    commissionInfoIndex: Number,
    eligibleToRun: Date,
    attempts: {type: Number, mongooseDefault: 0},
    permanentFailure: Boolean,
    updateTypes: [
      { type: String, enum: ['summary', 'open-job-postings', 'search-keys', 'from-commission-info', 'from-company', 'update-introduction-videos', 'time-out-mol-update', 'plugin']}
    ],
    pluginUpdateType: String,
    data: Object,
    targetUpdateTypes: [
      { type: String, enum: ['summary', 'open-job-postings', 'search-keys']}
    ]
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('backgroundUpdateQueueEntryMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('BackgroundUpdateQueueEntry', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
