import Complex from '../complex'
import ObjectId from '../object-id'
import {R2Author, R2IntroductionComment} from './r2-common'
import now from '../now';

const TestResult = new Complex({
  testId: String,
  grade: Number,
  name: String,
  done: Date,
  resultFileLocation: String
})

const TestResultSet = new Complex({
  testSet: String,
  allDone: Boolean,
  testResults: [TestResult]
})


export const R2CommissionInfo = new Complex({
  _id: ObjectId,
  commission: {type: ObjectId, mongooseRef: 'Commission', index: true},
  rating: {type: Number, optional: true},
  ratings: [new Complex({_id: ObjectId, rating: Number, user: R2Author, date: Date})], // obsolete
  markedForSelection: {type: Date, optional: true},
  selected: {type: Date, optional: true},
  reserved: {type: Date, optional: true, allowNull: true},
  application: {type: Date, optional: true},
  applicationUpdated: {type: Date, optional: true},
  terminated: {type: Date, optional: true},
  terminationMessageSent: {type: Date, optional: true},
  commissionDeleted: new Complex({date: Date, wasReserved: Date}),
  pipelineState: String,
  aptitudeTestsSent: new Complex({
    initial: {type: Date, optional: true},
    advanced: {type: Date, optional: true}
  }),
  aptitudeTestResults: new Complex({
    initial: TestResultSet,
    advanced: TestResultSet
  }),
  workExperience: {type: ObjectId},
  interviews: [Date],
  rbnInterview: new Complex({
    sent: {type: Date, optional: true},
    answered: {type: Date, optional: true}
  }),
  interviewDate: new Complex({
    stateActivated: {type: Date, optional: true},
    date: {type: Date, optional: true},
    duration: Number,//minutes
    notified: {type: Date, optional: true},
    interviewer: ObjectId
  }),
  introduction: new Complex({
    stateActivated: {type: Date, optional: true},
    date: {type: Date, optional: true},
    exportedToIntroductionTool: {type: Date, optional: true},
    introductionCreated: {type: Date, optional: true},
    introductionToolId: String,
    recruiterReview: String,
    recruiterHighlight: String,
    introducedBy: R2Author,
    introductionComments: [
      R2IntroductionComment
    ]
  }),
  contract: new Complex({
    exists: Boolean,
    host: String,
    externalId: {type: String, optional: true},
    notDeletable: {type: Boolean, optional: true},
    date: {type: Date, optional: true}
  }),
  jobPeriod: new Complex({
    startDate: {type: Date, optional: true},
    endDate: {type: Date, optional: true}
  }),
  events: [
    new Complex({
      date: { type: Date, mongooseDefault: now},
      eventType: String,
      user: {type: R2Author, optional: true},
      refId: {type: String, optional: true}
    })
  ]
})
