import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    name: new Complex({
      first: String,
      last: String
    }),
    email: String,
    mobilePhone: String,
    title: String,
    company: { type: ObjectId, mongooseRef: 'Company' },
    integrationPointId: Object,
    deleted: Boolean,
    customerIds: [{type: String, index: true}]
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('contactPersonMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('ContactPerson', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
