import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,

    name: String,
    atsLanguage: {type: String, enum: ['fi', 'en'], mongooseDefault: 'fi'},
    i2Channels: [String],
    customerId: {type: String, index: 'unique'},
    directoryName: String,
    defaultIndustry: String,
    noReplyEmailAddress: String,
    contactEmailAddress: String,
    profileDeletionEmailAddress: String,
    sendEmailUsingCustomerDomain: Boolean,
    o2LogoLink: String,
    languageCodes: [String],
    o2MainSite: String,
    useRecruitingPermissions: Boolean,
    useEarlyIntroduction: Boolean,
    useStandaloneIntroduction: Boolean,
    recrightAPIKey: String,
    billableCompany: new Complex({
      businessId: String,
      companyName: String,
      companyNumber: String
    }),
    localizedAttributes: [
      new Complex({
        languageCode: String,
        privacyPolicyUrl: String,
        privacyPolicyDisclaimer: String,
        o2Footer: String,
        openPositionsHeader: String,
        openPositionsSubHeader: String,
        industrySpecific: [new Complex({
          industry: String,
          terminationMessageTemplate: String,
          applicationReceivedEmail: String,
          applicationSentPage: String,
          recrightInviteMessage: String,
          interviewInvitationMessage: String,
          timezone: String,
          introduction: new Complex({
            description: String,
            shortDescription: String
          })
        })],
        applicationTextPlaceholder: String
      })
    ],
    defaultCurrency: String,
    documents: [
      new Complex({
        filename: String,
        document: {type: ObjectId, mongooseRef: 'Document'}
      })
    ],
    styles: new Complex({
      customLess: String,
      variables: [new Complex({
        name: String,
        value: String
      })],
      images: [new Complex({
        filename: String,
        url: String
      })]
    }),
    analyticsPixels: new Complex({
      googleTagManager: String,
      facebook: String,
      twitter: String,
      linkedin: String
    }),
    clientPlugins: [
      new Complex({
        name: String,
        options: Object
      })
    ],
    serverPlugins: [
      new Complex({
        name: String,
        options: Object
      })
    ]

  }
}

export default {
  get mongoose() {
    return toMongooseSchema('customerMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Customer', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
