import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    creator: R2Author,
    body: String,
    format: {type: String, enum: ['plaintext', 'markdown']},
    isPublic: Boolean, // Allow anyone to read the document -- especially o2,
    customerId: {type: String, index: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('documentMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Document', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
