import Complex from '../complex'
import ObjectId from '../object-id'

export const R2CandidateFilters = new Complex({
  availability: new Complex({ from: Date, to: Date }),
  lastModified: new Complex({ since: Date }),
  transport: [String],
  tags: [
    new Complex({
      tag: String,
      exact: Boolean, // TODO: remove after migration
      locked: Boolean,
      negate: Boolean
    })
  ],
  searchTerm: [
    new Complex({
      searchTerm: String,
      locked: Boolean,
      negate: Boolean
    })
  ],
  locationsExtended: [
    new Complex({ type: { type: String, enum: ['exact', 'neighborhood'] }, value: String })
  ],
  sex: String, // 'm' || 'f'
  age: new Complex({
    min: {type: Number, optional: true},
    max: {type: Number, optional: true}
  }),
  interviewedByIndustries: [String],
  interviewer: [
    new Complex({
      user: {type: ObjectId, mongooseRef: 'User'},
      name: new Complex({first: String, last: String})
    })
  ],
  interviewed: [{type: String, enum: ['interviewed']}],
  employeeName: [
    new Complex({first: String, last: String})
  ],
  contractEnding: new Complex({
    rangeStartDays: Number,
    rangeEndDays: Number
  }),
  phone: [String],
  postcode: [String],
  noActiveContract: Boolean,
  employedBefore: Boolean,
  notEmployedBefore: Boolean
})
