import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    name: new Complex({
      en: {type: String, index: true},
      fi: {type: String, index: true},
      no: {type: String, index: true, optional: true},
      pl: {type: String, index: true, optional: true},
      et: {type: String, index: true, optional: true}
    }),
    deleted: Boolean,
    code: String
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('languageMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Language', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
