import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'


const schema: Schema = {
  fields: {
    _id: ObjectId,
    subject: String,
    message: String,
    htmlMessage: Boolean,
    medium: { type: String, enum: ['email', 'sms'] },
    messageType: { type: String, enum: ['termination', 'general', 'interview-invitation', 'merge'] },
    sentAnonymously: Boolean,
    sentBy: R2Author,
    senderAddress: String,
    replyToAddress: String,
    receiverAddress: String,
    createdAt: { type: Date, mongooseDefault: now },
    recipients: [{ type: ObjectId, mongooseRef: 'Person', index: true }],
    commission: { type: ObjectId, mongooseRef: 'Commission', index: true, optional: true },
    interviewDate: Date,
    interviewLocation: String,
    sentForService: String,
    interviewDuration: Number, //in minutes
    customerId: {type: String, index: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('messageMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Message', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
