import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    recipients: [{type: ObjectId, mongooseRef: 'User'}],
    isGlobal: Boolean,
    isUniversal: Boolean,
    acknowledgedBy: [{type: ObjectId, mongooseRef: 'User'}],
    expirationDate: {
      type: Date,
      optional: true
    },
    duration: Number,
    createdAt: {type: Date, mongooseDefault: now},
    title: String,
    translateTitle: Boolean,
    type: {type: String, enum: ['announcement', 'introduction', 'error', 'messages-sent']},
    group: String,
    link: new Complex({
      exists: Boolean,
      label: String,
      linkType: {type: String, enum: ['external', 'introduction', 'introduction-candidate']},
      linkData: Object
    }),
    translateBody: Boolean,
    text: String,
    isDeleted: Boolean,
    acute: Boolean,
    variables: Object,
    customerId: {type: String, index: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('notificationMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Notification', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
