import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    name: String,

    personEmail: String,
    authorEmail: String,
    author: R2Author,
    createdAt: Date,

    profileVideo: Boolean,
    interviewRbnId: { type: String, index: true },
    candidateRbnId: String,
    avatarUrl: String,
    customerId: {type: String, index: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('rbnInterviewMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('RbnInterview', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
