import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    date: { type: Date, index: true},
    commissionsCreated: {type: Number, mongooseDefault: 0},
    commissionsCreatedByIndustry: [new Complex({amount: Number, industry: String})],
    logins: {type: Number, mongooseDefault: 0},
    loginsByIndustry: [new Complex({amount: Number, industry: String})],
    applicationsCreated: {type: Number, mongooseDefault: 0},
    applicationsCreatedByBusinessBranch: [new Complex({amount: Number, businessBranch: String})],
    applicantSearches: {type: Number, mongooseDefault: 0},
    applicantSearchesByIndustry: [new Complex({amount: Number, industry: String})],
    applicationsInOpenCommissions: {type: Number, mongooseDefault: 0},
    applicationsInOpenCommissionsByIndustry: [new Complex({amount: Number, industry: String})],
    customerId: {type: String, index: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('usageAggregationMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('UsageAggregation', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
